@@ -27,7 +27,10 @@ def warnings_recent_content():
     }
 
 @register.inclusion_tag('elements/form.html')
-def simple_form(form):
+def simple_form(frontadmin_form):
     return {
-        'form': form
+        'form': frontadmin_form.form,
+        'form_title': frontadmin_form.form_title,
+        'form_submit': frontadmin_form.form_submit,
+        'form_class': frontadmin_form.form_class
     }
\ No newline at end of file
